#
# spec file for package ART
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} < 1590
%global force_gcc_version 12
%endif

%if (0%{?suse_version} >= 1590) || ("%{_project}" == "graphics")
%bcond_without art_ctl
%else
%bcone_with    art_ctl
%endif

Name:           ART
Version:        1.25.2
Release:        1.2
Summary:        Rawtherapee fork with masks and simplified UI
License:        GPL-3.0-only
URL:            http://art.pixls.us/
Source:         https://github.com/artpixls/ART/releases/download/%{version}/%{name}-%{version}.tar.xz
# No signed tarball quite yet.
# Source:         https://github.com/artpixls/ART/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
# https://keys.openpgp.org/vks/v1/by-fingerprint/942FCFB1CBE1E38928A1A6BEA94D951156835A5D
Source2:        %{name}.keyring
Patch0:         fix-missing-lm.patch
BuildRequires:  OpenColorIO-devel
%if %{with art_ctl}
BuildRequires:  ctl-devel
%endif
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc%{?force_gcc_version}-c++ >= 12
BuildRequires:  glibmm2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libraw-devel
BuildRequires:  mimalloc-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(fftw3l)
BuildRequires:  pkgconfig(gail-3.0)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-broadway-3.0)
BuildRequires:  pkgconfig(gdk-wayland-3.0)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gdkmm-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gmodule-no-export-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-broadway-3.0)
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
BuildRequires:  pkgconfig(gtk+-wayland-3.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libiptcdata)
BuildRequires:  pkgconfig(libprofiler)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libtcmalloc)
BuildRequires:  pkgconfig(libtcmalloc_debug)
BuildRequires:  pkgconfig(libtcmalloc_minimal)
BuildRequires:  pkgconfig(libtcmalloc_minimal_debug)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)

%description
A free, open-source, cross-platform raw image processing program. ART is a derivative of the popular RawTherapee, trading a bit of customization and control over various processing parameters for a simpler and (hopefully) easier to use interface, while still maintaining the power and quality of RawTherapee.

%prep
%autosetup -p1

%build
# Upstream recommended '-O3' optimisation, do not change
export CFLAGS="%(echo %{optflags} | sed 's/-O2/-O3/' | sed 's/-D_FORTIFY_SOURCE=2/-D_FORTIFY_SOURCE=3/')"
export CXXFLAGS="$CFLAGS"

%if 0%{?force_gcc_version}
export CC=gcc-%{?force_gcc_version}
export CXX=gcc-%{?force_gcc_version}
%else
export CC=gcc
export CXX=gcc
%endif

%cmake \
%if 0%{?force_gcc_version}
    -DCMAKE_CXX_COMPILER=%{_bindir}/g++-%{?force_gcc_version} \
%endif
    -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now" \
    -DCMAKE_CXX_FLAGS="$CXXFLAGS" \
    -DCMAKE_C_FLAGS="$CFLAGS" \
    -DCACHE_NAME_SUFFIX="" \
    -DENABLE_LIBRAW="ON" \
%if %{with art_ctl}
    -DENABLE_CTL="ON" \
    -DCTL_INCLUDE_DIR="%{_includedir}/CTL" \
%endif
    -DENABLE_OCIO="ON"
%cmake_build

%install
%cmake_install
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/%{name}.desktop
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{_docdir}/%{name}

%fdupes %{buildroot}/%{_prefix}

%files
%{_bindir}/ART
%{_bindir}/ART-cli
%{_libdir}/librtengine.so
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/applications/%{name}.desktop
%{_mandir}/*/%{name}*
%{_docdir}/%{name}

%changelog
* Sat Feb 15 2025 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.25.2:
  * ThumbBrowserEntryBase::draw: check that the surface has been
    created before drawing
  * linux workflow: ensure a recent version of ninja is available
  * linux64 workflow: include glib 2.83 in the linux binary
    distribution
  * added dcp profile for Panasonic S5mkII
* Sat Feb  1 2025 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.25.1:
  * placesbrowser: renamed SetRow to setRow
  * [BugFix] Check default dir before add existing directory to
    'Places'
  * [BugFix] Quick zoom out & zoom in makes zoom center to image
    center.
  * fixed (another) typo in linux_x64 bundle creation in debug mode
  * fixed typo in linux_x64 bundle creation in debug mode
  * fixed typo in linux/bundle_ART
  * linux workflow: added option to build debug versions
  * Re-center the crop window on mouse click.
  * fixed typo in bundle_ART scripts
- Updates from 1.25.0:
  * fixed image preview when output profile is set to "passthrough"
  * fixed one more typo
  * force the use of sRGB as monitor profile when running under
    wayland
  * removed obsolete options
  * further tweaks to the tooltips in the French translation
  * performance: enable thumbnail caching by default
  * one more tweak to the French translation
  * fixed French translation markup errors
  * updated camera matrices
  * updated WB presets
  * updated translations
  * fixed color management in inspector mode when ART_OS_COLOR_MGMT
    is defined
  * updated Italian translation
  * fixed homepage url in help msg
  * renamed options.rtdir to options.user_config_dir and argv0 to
    options.ART_base_dir
  * refactored code for color management of GUI elements
  * consider the default monitor profile also when drawing brush
    strokes and false colors
  * GUI: consider the default monitor profile when drawing
    gradients and histograms
  * avoid noise amplification when applying CAT for WB
  * added option to override the quartz colorspace with env var
    (for debugging)
  * procparams: set the default output profile to RTv2_sRGB
  * rgb2monitor: do not use openmp if multiThread is false
  * include GTK immodules in the linux bundle
  * filecatalog: protect calls to FileCatalog::previewReady with
    the GUI lock
  * imagesource: do not use openmp for color space conversions in
    thumbnails
  * linux bundle_ART: include gio vfs modules
  * procparams: support for saving paths relative to the user home
    dir
  * filecatalog: protect _refreshProgressBar with a gui lock
  * updated README
  * dynamic profiles: added button to reset to default (built-in)
    rules
  * colorcorrection: added gamma slider in "HSL factors" mode
* Mon Jan  6 2025 Marcus Rueckert <mrueckert@suse.de>
- consistently set CC/CXX variables
- enable CTL support in the devel project
* Sat Jan  4 2025 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.24.5:
  * CTL scripts: allow translating also tooltips
  * thumbnail: ensure return value of Thumbnail::getColorLabel() is
    valid
* Fri Dec 20 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.24.3:
  * enlarge the cache for CTL scripts
  * iccstore: special case checksum computation for the builtin
    sRGB profile
* Tue Dec 17 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.24.2:
  * added "1:1" icons to local contrast and texture boost panels
  * added function getExecutablePath()
  * added support for reading color labels from xmp metadata
    embedded in the image
  * camconst: added dcraw matrix for SIGMA DP1
  * camconst: removed hardcoded (wrong) black level for Nikon D5
  * CTL: ensure we keep a reference to Ctl::Interpreter around
    while there are Ctl::FunctionCallPtrS alive
  * filecatalog: use idle_register instead of GThreadLock for GUI
    updates from other threads
  * fixed compilation error when not using libraw
  * fixed propagation of scroll events to the shortcut manager
  * fixed truncation of local contrast curve when initially opened
  * gauss: use AlignedBuffer instead of stack-allocated arrays
  * getExecutablePath: change argument type to const char *
  * improved handling of omp pragmas in evaluating CTL scripts
  * improved keyboard navigation in the batch queue
  * pathutils: added missing include directive
  * print messages about CLF and CTL cache misses when verbosity >
    1
  * rawimage: do not read black/white levels from camconst for
    foveon cameras when using libraw
  * rawimage: don't recompute black levels for DNG files
  * removed (confusing) option to partially copy a profile to the
    clipboard
  * search for language translation files also in the ctlscripts
    directories
  * simplified implementation of FileCatalog::_refreshProgressBar
  * smoothing: added wavelets mode
  * take into account the selected UI font size in the inspector
    and editor info panels
  * updated Hungarian translation
* Sat Oct 12 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.24.1:
  * file browser: improved keyboard navigation for session
    management
* Thu Oct 10 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.24:
  * colorcorrection: allow user-defined order of CTL plugins
  * improved bundle scripts to allow including the ART-imageio plugins
  * imgiomanager: only print error messages when settings->verbose > 0
  * better keyboard navigation for emptying the trash
  * file browser: improved keyboard navigation when applying filters
  * added preliminary support for Canon R5markII and R1
  * fixed raw crop for ILCE-7CR and ILCE-7RM5 in 16-shot pixel shift mode
  * added linear rec 709 icc profile
- Add fix-missing-lm.patch.
* Tue Aug  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.23:
  * updated translations: Deutsch, Francais, Maygar, Catala
  * updated camera matrices:
    FUJIFILM GFX 100S II, FUJIFILM X-T50, GOOGLE PIXEL 8A FRONT
    CAMERA, GOOGLE PIXEL 8A ULTRAWIDE CAMERA, GOOGLE PIXEL 8A WIDE
    CAMERA, IPAD14,10 BACK CAMERA, IPAD14,11 BACK CAMERA, IPAD14,8
    BACK CAMERA, IPAD14,9 BACK CAMERA, IPAD16,3 BACK CAMERA,
    IPAD16,4 BACK CAMERA, IPAD16,5 BACK CAMERA, IPAD16,6 BACK
    CAMERA, PANASONIC DC-GH7, PANASONIC DC-S9, SONY XPERIA 1 VI
    FRONT CAMERA, SONY XPERIA 1 VI ULTRAWIDE CAMERA, SONY XPERIA 1
    VI WIDE CAMERA, SONY XPERIA 1 VI ZOOM CAMERA, SONY XPERIA 5 V
    FRONT CAMERA, SONY XPERIA 5 V ULTRAWIDE CAMERA, SONY XPERIA 5 V
    WIDE CAMERA
  * more fine tuning to curve support in CTL scripts
  * CTL scripts: started adding support for curve type parameters
  * CTL scripts: improved GUI customizability for curve parameters
  * metadata panel: added word wrapping for processing notes
  * added support to saving notes in the arp sidecars
  * adjuster: reverted "double click to reset" behaviour for spin
    buttons as it was buggy
  * adjuster: exclude the spin buttons from the "double-click to
    reset" effect
* Wed Jun 19 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.22.1:
  * updated camera color matrices for OM Systems OM-1mkII and OM-5
  * reset adjusters with double click
  * exifpanel: improved tooltips for tags
  * lensexif: avoid division by 0 when computing Olympus ca coeffs
* Wed May 29 2024 Paolo Stivanin <info@paolostivanin.com>
- Add dependency to CTL on Tumbleweed.
* Mon May 27 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.22:
  * brush mask: added ctrl-z / ctrl-shift-z for undo/undo all
    during brush editing
  * cmake: do not link against mimalloc when using ASAN
  * colortemp.h: added missing "#include <array>"
  * CTL: take into account the CTL_MODULE_PATH env var when loading
    modules
  * file browser: show the number of selected files when >1
  * metadata: explicitly handle the case of exiftool not found
  * procparams: disable histmatching when loading arp files with an
    already-computed tone curve
  * rawimage: properly extract the raw optical black for bayer
    sensors when using libraw
  * rawimage: simple workaround for libraw issue with some xtrans
    DNG files produced by dnglab
  * smoothing: added simple halation
  * spot removal: fixed bad preview when denoise is enabled
  * subprocess: fixed freeze happening when fork/exec failed in
    subprocess::popen
  * updated camera matrices
  * updated translations
  * updated WB presets
  * white balance: improved robustness in "extreme" situations
    (e.g. UV)
* Thu Apr 11 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.21.3:
  * updated camera matrices
  * color correction: properly refresh the curves displayed when
    changing the active region
  * camconst: updated raw_crop for Sony ILCE-7CR and ILCE-7RM5
  * camconst: fixed bug in overriding raw_crop entries from the
    user camconst.json
* Wed Mar 20 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to 1.21.2:
  * added DCP profiles for some Nikon Z cameras
  * camconst: added raw crop for the Sony A9mkIII
  * lens corrections from metadata for Olympus cameras ported from
    darktable
  * added DCP profile for FUJI GFX 100
  * camconst: added PDAF pattern for the Fuji GFX 100 cameras
  * CTL luts: use the current working space by default if none is
    specified
  * tweaked verbosity messages of PDAF lines filter
  * updated camconst with more pdaf patterns for sony cameras
    (backported from RT)
  * added higher resolution image of the logo
  * filebrowser: fixed segfault when exiting the search box when
    all thumbnails are filtered out
  * fixed lensfun version detection for deprecated API removal
  * fixed compilation errors with lensfun master
  * stdimagesource: detect special ART ICC profiles for unbounded
    conversion
  * fixed detection of embedded profiles for non-raw thumbnails
  * masks: added global opacity slider
  * denoise: do not apply extra gamma for non-raw images
  * tone curve: avoid artifacts in highlights when using negative
    contrast with "Neutral" mode
  * cmakelists: sanitize PROC_LABEL to avoid shell syntax errors
* Wed Jan 24 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to 1.21.1:
  * updated translations
  * slightly increased precision for CTL luts in low-quality mode
    (used for thumbnails)
  * fixed metadata display on thumbnails for png files
  * updated camera matrices
  * updated WB presets
  * local editing: make "copy region" insert after the current
    selection
  * ctl luts: fixed setting gui group for PT_CHOICE params
  * added fast export support to "send to external editor"
  * rawimage: put global black level for xtrans files where the
    code expects to find it
  * texture boost: increased range of detail threshold slider
  * exifpanel: improved metadata validators
  * profiles: tweaked "Simple Film Curve"
  * logenc: use 2 digits for black ev
  * improved support for translation of CTL scripts
  * added support for user-specific translation files
  * color wheel: edit by hue/saturation instead of x/y with right
    click
  * CTL lut params: allow to specify also a tooltip (markup) string
    as last parameter (after group name)
  * improved LUT precision for fast CTL rendering on the preview
  * local editing: add new region after the current selected one
    instead of always appending at the end
  * tone curve: added base curve control for seamless tone mapping
  * cli: accept relative filenames in --check-lut
  * tweaks to handling quality settings for CTL scripts
  * continued removing dead code
  * dynamic profiles: changed how "image type" filter works now it
    allows to distinguish between raw and non-raw images. For HDR
    and/ or PS, custom exif tags can be used
  * removed some dead code
  * further improvement in loading of lut params
  * improved robustness of CTL scripts support
  * Moving FileBrowserEntry static variable initialization to a
    dedicated method. Fixes a crash introduced a previous commit.
  * CTL interpreter: add ART ctlscripts to the module search path
* Thu Dec  7 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to 1.21:
  * sigmoid.ctl: added white point control
  * updated wb presets
  * CTL: fixed glitch in parameter parsing
  * updated Dutch translation
  * updated French translation
  * improved error reporting for invalid CTL scripts
  * main-cli: fixed bugs in --check-lut
  * ART-cli: added option --check-lut to aid debugging luts
    (esp. CTL scripts)
  * slightly reduce 3d lut size of fast preview of CTL scripts
  * added generic LUT3D class
  * small tweak to bundled profiles
  * added option to speed up CTL script application in preview
  * added reset button for clut parameters
  * moved CTL scripts to a separate repo
  * improved wb correction formula in wbchmix.ctl
  * fix focus distance for Nikon Z cameras
  * minor gui tweaks
  * sigmoid: added support for base primaries
  * added translation strings to plugins and builtin luts
  * fixed glitches in color correction UI with plugins
  * added some bundled luts and CTL scripts
  * some more tweaks to the support for CTL scripts
  * colorcorrection: fixed glitches
  * clutstore: code cleanup, get rid of need for LUTs for
    parametric CTL scripts
  * colorcorrection: reorder pixel-level applications to make
    parametric luts faster
  * CTL LUT: use tabulation to avoid massive slowdown in
    apply_single with complex uniform parameters
  * parametric CTL LUTs: improved comment
  * parametric CTL LUTs: fixed glitches and improved logging
  * added support for parametric CTL luts
  * renamed HaldCLUT to CLUT
  * improved cache invalidation for LUTs
  * Added support for building ART with the ACES CTL interpreter
  * neutral tone curve: always use rec2020 for calculating the base
    hues for the final shifts
  * neutral tone curve: further tweaks to hue shifts
  * logenc: improved implementation of "highlights precompression"
  * neutral tone curve: alternative criterion for hue shifts and
    desaturation
  * neutral tone curve: added some hue shifts to (try to) consider
    perceptual effects
  * tuned threshold for hot pixel detection for xtrans
  * procparams: fix missing auto-computed settings when comparing
    ProcParams instances
  * procparams: properly consider auto-computed settings when
    comparing ProcParams instances
  * basic hot/dead pixel filter for xtrans cfa
  * spot removal: properly take film negative into account
  * added option to specify the currently-active snapshot in the
    output file name pattern
* Fri Oct  6 2023 Paolo Stivanin <info@paolostivanin.com>
- Use better macro for selecting a newer GCC on Leap.
* Thu Sep 14 2023 Paolo Stivanin <info@paolostivanin.com>
- Use GCC11 on Leap.
* Thu Sep 14 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to 1.20.2:
  * histogram: fixed bug in showing the pixel values under the
    cursor in log modes
  * fixed glitch in opening pictures that are filtered out from the
    current file catalog
  * rawimage: use internal decoder for floating-point DNGs
  * CLF-LUTs: invalidate cache when content of clf files change
  * moved film simulation before tone curve (with backwards-
    compatibility option added)
  * rgb curves: show the other curves in the curve editor
  * restored shortcuts for the Lab tool
  * masks: do not perform guided filtering if blur is set to the
    minimum val
  * texture boost: make the "iterations" slider better behaved
  * updated labeling of some tools - Sharpening -> Capture
    Sharpening - Texture Boost -> Texture Boost / Sharpening
  * wbpresets: use the internal "make+model" key to match camera
    preset info
  * fixed another glitch in displaying the "triangle" indicator for
    the currently-selected thumbnails
  * updated translations
  * updated camera matrices
  * updated WB presets
* Thu Jul 13 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to 1.20.1:
  * updated camera matrices to increase chances of matching names
    of smartphones
  * fixed glitch in displaying the "triangle" indicator for the
    currently-selected thumbnails
  * fix wb multipliers corner case for monochrome images
  * rawimage: allow 4-color linear DNG files
  * Porting fix for truncated curve widget from RT
  * metadata: fixed focus distance computation, a wrong focus
    distance calculation was affecting lensfun vignetting
    correction
  * theme: better visual feedback for selected thumbnails in the
    file browser
  * added wb presets and dcp profile for Canon Powershot G5XmkII
  * file catalog: made background color of selected thumbnails
    slightly brighter
* Thu May 18 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to 1.20:
  * updated camera matrices
  * updated WB presets with latest additions from darktable
  * neutral tone curve: disable the now-unnecessary output
    hue blending
  * neutral tone curve: one more typo in the application of
    the whitepoint 2
    one more typo in the application of the whitepoint
  * neutral tone curve: fixed bug in computing the conversion
    matrices for gamut mapping
  * tonecurve: fixed bug in setting the whitepoint for the LUT
  * prevent segfault when switching images while editing the crop
  * updated German and Hungarian translations.
  * procparams: fixed corruption of stroke lists due to rounding
    errors in HalfFloats with large integers
  * changed default values for some GUI preferences including
    histogram position
  * rawimage: do not handle images with more than 3 colors
* Mon Mar 27 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.19.3:
  * vignette: update the on-screen center widget when the crop changes
  * thumbnail: do not try to load from cache after the first failure
  * added raw crop for Fujifilm X-T5
  * updated camera matrices and wb presets
  * spot removal: added button to bypass heavy tools when editing spot
  * smoothing: fixed bug with mask application in lens/motion blur modes
  * improved formatting of exiftool makernotes
  * metadata: added option to show makernotes with exiftool
  * improve spot removal performance in preview window
  * improve description of system monitor profile detected
  * dcrop: avoid recomputing transform when not needed
  * limit scale for output sharpening in preview to 1.0
  * lens blur: apply inpainting to the unaffected areas to better simulate a "large aperture background separation" effect
* Mon Jan 30 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.18.1:
  * replace omp_get_max_threads() with omp_get_num_procs()
  * denoise: more aggressive caching of auto chroma coefficients
  * fixed corrupted thumbnails when using the libraw decoder with a custom raw crop
  * trying to speedup denoise with automatic chroma
  * denoise: try avoiding recomputation of automatic chrominance denoise when not necessary
  * saveasdlg: fixed bug in setting filename
  * try to recover if the exiftool process returns an error
  * better integration with exiftool (reuse the same process instead of spawning a new one every time)
  * added support for lcms2 fast float
* Tue Jan  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.18.0:
  * properly refresh the progress bar when loading thumbnails
  * fixed bugs with launching external editor on windows when filename is not ASCII or contains spaces
  * session save: ask before overwriting
  * imageio: further improvements to ease bundling of image load/save plugins on windows
  * file catalog: properly update the session when renaming/moving/deleting files
  * local editing: do not include the effects of "show mask" in output images
  * file rename: added %%# pattern for numeric suffixes of filenames
  * automatically add ".ars" extension when saving sessions
  * improved support for sessions
  * always apply the tone curve when enabled (even if it is an identity)
  * filecatalog: try to avoid refreshing directories while files are still being modified
  * metadata: fixed uninitialized value in star rating
  * film negative: fix behaviour of "pick neutral spots"
* Wed Dec  7 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.17.2:
  * fixed bad interaction between film negative and dehaze or dynamic range compression
  * fixed regression in loading pixel-shift raw files
  * draw the crop guides in the batch queue thumbnails
  * spot removal: fixed history messages
  * PDAF lines filter: fixed oob accesses
  * added script to import wb presets from darktable
  * added DCP profiles from RT
  * film negative: show deprecation warning for "color space"
  * grain: removed redundant "scale" parameter
  * metadata: write star rating to the output image
  * highlight recovery: fixed crash due to typo
  * camconst: added raw_crop for Fuji X-H2
  * support camconst raw_crop when using the libraw decoder
  * dcraw: reject RGBA tiff files
  * replaced "balanced" highlight recovery with "inpaint opposed" from darktable
* Wed Nov  2 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.16.4:
  * crop window: reset the tool to "hand" after a "spot wb" action
  * allow to save pngs uncompressed
  * improved support for custom loaders and savers
  * metadata: trying to improve lens identification for canon cameras
  * reverted thumbnail.cc change due to glitch in the file browser (issue #267)
  * trying to improve the (perceived) responsiveness of the file browser
* Fri Oct  7 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.16.3:
  * editorpanel: fixed refresh of image area when switching images
  * clutstore: do not search for working profile in the file name for CLF LUTs
  * pipeline: move film simulation earlier (right after tone curve)
  * tone equalizer: improved robustness of regularization with hdr images
  * avoid infinities when loading and manipulating hdr images
  * exposure: do not use a LUT, it's not needed
  * fixed bug in applying partial profiles in append mode from the combobox
  * filecatalog: let the user choose which sidecars to affect when deleting a file
  * colorcorrection: slightly extend the range of offset sliders
  * tonecurve: fixed glitch in expansion of curve according to the white point
  * denoise: testing new ways of adjusting parameters according to the scale factor
* Tue Sep  6 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.16.2:
  * Fixed bug in fast-path for output profile application.
  * Fixed segfault when the thumb cache contains an invalid date.
  * Update camera matrices.
  * Update translations.
  * LUT: protect against NaN indices.
  * Img out: added custom ICC profile conversion to avoid clamping to [0,1].
  * Color correction: added LUT mode.
  * Handle linear DNG as other raw images.
  * Tonecurve: improved range for the saturation2 curve.
  * Denoise: some tweaks to the detail mask.
  * Filmsimulation: added support for ACES clf LMT LUTs using OpenColorIOv2.
  * Logenc: added highlight precompression.
  * Tonecurve: allow whitepoint to go up to 100 (~10000 nits).
- Drop fix-ppc-cflags.patch
* Thu Aug 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Disable LTO, since it makes the program crashing.
* Wed Aug 17 2022 Paolo Stivanin <info@paolostivanin.com>
- Add fix-ppc-cflags.patch: set mcpu=native instead of march=native
  on ppc64, otherwise compilation will fail.
* Mon Jul 25 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.15:
  * Many changes, see
    https://bitbucket.org/agriggio/art/branches/compare/1.15%%0D1.14
- Use released tarballs instead of git service for source.
- Drop add_releaseinfo.patch: No longer needed when using released
  source tarballs.
- Drop duplicated options passed to cmake.
- Drop post(un) scriptlets running update-desktop-database and
  gtk-update-icon-cache: these are taken care of by file triggers.
* Wed Jun 29 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.14 (no changelog)
* Tue Apr 19 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.13 (no changelog)
* Fri Feb 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.12.1 (no changelog)
* Fri Dec 31 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.12 (no changelog)
* Wed Dec 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.11.1 (no changelog)
* Mon Nov  8 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.10.1 (no changelog)
* Mon Jul 19 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.3 (no changelog)
* Fri May 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.9.1:
  * New gradient mask
  * Updated the CR3 decoder to the latest from libraw
  * Added option to periodically auto-save arp sidecars
  * Slightly reworked the UI of the Log Tone Mapping tool
  * A bunch of bug fixes
* Fri Apr  2 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.3 (no changelog)
* Tue Feb 23 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.2 (no changelog)
* Thu Feb 18 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8.1 (no changelog)
* Fri Feb  5 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.8:
  * slightly improved “colour propagation” highlight recovery
    (trying to mitigate artifacts that might sometimes occur)
  * added Spanish and Catalan translations
  * changed the UI of the color/tone correction tool in “HSL factors” mode,
    from sliders to color wheels
  * added “luminance mode” for color correction with “separate RGB channels”
  * improved RCD demosaicing code, taken from RT
  * added a new “Glow” mode to the smoothing filter, inspired by recent discussions here
  * simplified and improved the “final smoothing” part of the “noise reduction” tool
    (median is gone, replaced by a custom-tweaked non-local means implementation)
  * you can now select whether you want to use “hovering navigation” in the inspector
  * the brush mask now includes a “live preview” of the brush strokes
* Mon Jan  4 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.7.1:
  * improved usability of the brush mask, now strokes are smoother
    (you can go faster and still get a continuous stroke) and if you
    have a drawing tablet the brush radius and/or its hardness
    can be made pressure-sensitive
  * added support for lens correction parameters embedded
    in EXIF metadata
  * improved batch renaming, now supporting also moving to
    different directories
  * added support for Fuji GFX 100 pixel-shift files
    (both 4- and 16-frame), in combination with the make_arq 2 tool.
  * added support for using the “fast float” plugin of LCMS2
    for (significantly) faster color space conversions
  * various bug fixes
* Tue Dec  1 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.6.1 (no changelog)
* Tue Nov 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.6 (no changelog)
* Fri Oct 23 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.4 (no changelog)
* Thu Sep 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.3 (no changelog)
* Wed Sep  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.0:
  * added support for camera-specific white balance presets
  * added support for manipulating WB by setting the R,G,B multipliers
  * added input/output saturation to the colour correction module
  * added support for embedding the processing parameters inside the
    (XMP) metadata of the output images
  * added "saturation control" to the dynamic range compression module
  * added new experimental "dynamic row noise" filter
    (under Raw Bayer -> preprocessing) to fix colour banding occurring
    when taking long exposures with some Canon cameras
  * tweaked the default theme (for GTK >= 3.20)
* Tue Jun 30 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4.1 (no changelog)
* Fri Jun 19 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.4 (no changelog)
* Mon Jun  8 2020 Paolo Stivanin <info@paolostivanin.com>
- Adding -fno-tree-loop-vectorize due to https://github.com/Beep6581/RawTherapee/issues/5749
* Sat May  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3 (no changelog)
* Fri Apr 24 2020 Paolo Stivanin <info@paolostivanin.com>
- Initial release 1.2
- Add add_releaseinfo.patch
- Add fix-cmake.patch
